@@ -10,20 +10,20 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python2.7',
  'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -L/usr/lib/openssl-1.1',
+ 'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -L/usr/lib/openssl-1.1',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/python2/src=/usr/src/debug/python2 -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/python2/src=/usr/src/debug/python2',
+ 'CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/mnt/repo/src/python2/src=/usr/src/debug/python2 -flto=auto -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/mnt/repo/src/python2/src=/usr/src/debug/python2 -flto=auto',
  'CFLAGSFORSHARED': '-fPIC',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-optimizations' '--with-lto' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/python2/src=/usr/src/debug/python2' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -L/usr/lib/openssl-1.1' 'CPPFLAGS= -I/usr/include/openssl-1.1'",
+ 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-optimizations' '--with-lto' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/mnt/repo/src/python2/src=/usr/src/debug/python2 -flto=auto' 'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -L/usr/lib/openssl-1.1' 'CPPFLAGS= -I/usr/include/openssl-1.1'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/build/python2/src/Python-2.7.18/coverage.info',
- 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.18/lcov-report',
+ 'COVERAGE_INFO': '/mnt/repo/src/python2/src/Python-2.7.18/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/repo/src/python2/src/Python-2.7.18/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include  -I/usr/include/openssl-1.1',
  'CXX': 'g++',
@@ -71,7 +71,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
  'HAVE_BLUETOOTH_H': 0,
- 'HAVE_BROKEN_NICE': 1,
+ 'HAVE_BROKEN_NICE': 0,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -345,7 +345,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNSETENV': 1,
- 'HAVE_USABLE_WCHAR_T': 0,
+ 'HAVE_USABLE_WCHAR_T': 1,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
@@ -369,11 +369,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
  'INSTSONAME': 'libpython2.7.so.1.0',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -L/usr/lib/openssl-1.1',
+ 'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -L/usr/lib/openssl-1.1',
  'LDLAST': '',
  'LDLIBRARY': 'libpython2.7.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -L/usr/lib/openssl-1.1',
+ 'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -L/usr/lib/openssl-1.1',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python2.7',
  'LIBDIR': '/usr/lib',
@@ -416,7 +416,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPT': '-DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/python2/src=/usr/src/debug/python2',
+ 'OPT': '-DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/mnt/repo/src/python2/src=/usr/src/debug/python2 -flto=auto',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -440,7 +440,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing test_subprocess',
  'PSRCS': '\\',
- 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
+ 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
  'PURIFY': '',
  'PYLONG_BITS_IN_DIGIT': 0,
  'PYTHON': 'python',
@@ -450,13 +450,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': ':plat-linux2:lib-tk:lib-old',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHON_FOR_REGEN': 'python2.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/python2/src=/usr/src/debug/python2 -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -g -ffile-prefix-map=/build/python2/src=/usr/src/debug/python2 -I. -IInclude -I./Include  -I/usr/include/openssl-1.1 -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/mnt/repo/src/python2/src=/usr/src/debug/python2 -flto=auto -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/mnt/repo/src/python2/src=/usr/src/debug/python2 -flto=auto -I. -IInclude -I./Include  -I/usr/include/openssl-1.1 -fPIC -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_UNICODE_TYPE': 0,
+ 'PY_UNICODE_TYPE': 'wchar_t',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_UNICODE_SIZE': 4,
@@ -465,7 +465,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.18',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/repo/src/python2/src/Python-2.7.18',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -473,7 +473,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SHLIBS': '-ldl',
  'SHLIB_EXT': '".so"',
  'SIGNAL_OBJS': '',
- 'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
+ 'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 1,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
  'SIZEOF_FLOAT': 4,
@@ -508,7 +508,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.18 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/repo/src/python2/src/Python-2.7.18 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -522,7 +522,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'VERSION': '2.7',
  'WANT_SIGFPE_HANDLER': 0,
  'WANT_WCTYPE_FUNCTIONS': 0,
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
  'WITH_DYLD': 0,
  'WITH_LIBINTL': 0,
@@ -533,8 +533,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python2/src/Python-2.7.18',
- 'abs_srcdir': '/build/python2/src/Python-2.7.18',
+ 'abs_builddir': '/mnt/repo/src/python2/src/Python-2.7.18',
+ 'abs_srcdir': '/mnt/repo/src/python2/src/Python-2.7.18',
  'build': 'x86_64-pc-linux-gnu',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
